@@ -146,7 +146,7 @@ void *_prelude_realloc(void *ptr, size_t size)
 int prelude_read_multiline(FILE *fd, unsigned int *line, char *buf, size_t size) 
 {
         size_t i;
-
+        
         if ( ! fgets(buf, size, fd) )
                 return prelude_error(PRELUDE_ERROR_EOF);
 
@@ -159,14 +159,16 @@ int prelude_read_multiline(FILE *fd, unsigned int *line, char *buf, size_t size)
                 
         if ( buf[i] == '#' )
                 return prelude_read_multiline(fd, line, buf, size);
-                
-        i = strlen(buf);
-
-        while ( --i > 0 && (buf[i] == ' ' || buf[i] == '\n') );
+        
+        for ( i = strlen(buf) - 1; (buf[i] == ' ' || buf[i] == '\n' || buf[i] == '\r'); i-- ) {
+                buf[i] = 0;
+                if ( i == 0 )
+                        break;
+        }
         
         if ( buf[i] == '\\' )
                 return prelude_read_multiline(fd, line, buf + i, size - i);
-                
+              
         return 0;
 }
 
@@ -478,7 +480,8 @@ int _idmef_message_assign_missing(prelude_client_t *client, idmef_message_t *msg
                 if ( ! idmef_alert_get_messageid(alert) )
                         idmef_alert_set_messageid(alert, get_message_ident(ident));
 
-                if ( ! idmef_alert_get_create_time(alert) ) {
+                time = idmef_alert_get_create_time(alert);
+                if ( idmef_time_get_sec(time) == 0 ) {
                         ret = idmef_time_new_from_gettimeofday(&time);
                         if ( ret < 0 )
                                 return ret;
@@ -492,7 +495,8 @@ int _idmef_message_assign_missing(prelude_client_t *client, idmef_message_t *msg
                 if ( ! idmef_heartbeat_get_messageid(heartbeat) )
                         idmef_heartbeat_set_messageid(heartbeat, get_message_ident(ident));
 
-                if ( ! idmef_heartbeat_get_create_time(heartbeat) ) {
+                time = idmef_heartbeat_get_create_time(heartbeat);
+                if ( idmef_time_get_sec(time) == 0 ) {
                         ret = idmef_time_new_from_gettimeofday(&time);
                         if ( ret < 0 )
                                 return ret;
