@@ -60,7 +60,6 @@
 #define INDEX_FORBIDDEN (INT_MIN + 1)
 
 
-
 typedef struct idmef_path_element {
 
         int index;
@@ -85,7 +84,7 @@ struct idmef_path {
 
 typedef struct {
         int index;
-        idmef_path_t *path;
+        const idmef_path_t *path;
         idmef_message_t *message;
         prelude_bool_t reversed;
         prelude_bool_t delete_list;
@@ -185,12 +184,12 @@ static int build_name(idmef_path_t *path)
 
 
 
-static int idmef_path_get_internal(idmef_value_t **ret, idmef_path_t *path, unsigned int depth,
-                                   void *parent, idmef_class_id_t parent_class);
+static int idmef_path_get_internal(idmef_value_t **ret, const idmef_path_t *path,
+                                   unsigned int depth, void *parent, idmef_class_id_t parent_class);
 
 
 static int idmef_path_get_list_internal(idmef_value_t **value_list,
-                                        idmef_path_t *path, int depth,
+                                        const idmef_path_t *path, int depth,
                                         prelude_list_t *list, idmef_class_id_t parent_class)
 {
         int ret;
@@ -205,7 +204,7 @@ static int idmef_path_get_list_internal(idmef_value_t **value_list,
         prelude_list_for_each(list, tmp) {
                 value = NULL;
 
-                if ( parent_class != -1 )
+                if ( parent_class >= 0 )
                         ret = idmef_path_get_internal(&value, path, depth, tmp, parent_class);
                 else {                        
                         ret = idmef_value_new(&value, path->elem[depth - 1].value_type, tmp);
@@ -238,7 +237,7 @@ static int idmef_path_get_list_internal(idmef_value_t **value_list,
 
 
 
-static int idmef_path_get_nth_internal(idmef_value_t **value, idmef_path_t *path,
+static int idmef_path_get_nth_internal(idmef_value_t **value, const idmef_path_t *path,
                                        unsigned int depth, prelude_list_t *list,
                                        idmef_class_id_t parent_class, int which)
 {
@@ -265,7 +264,7 @@ static int idmef_path_get_nth_internal(idmef_value_t **value, idmef_path_t *path
 
 
 
-static int idmef_path_get_internal(idmef_value_t **value, idmef_path_t *path,
+static int idmef_path_get_internal(idmef_value_t **value, const idmef_path_t *path,
                                    unsigned int depth, void *parent, idmef_class_id_t parent_class)
 {
         void *child;
@@ -283,20 +282,20 @@ static int idmef_path_get_internal(idmef_value_t **value, idmef_path_t *path,
                 
                 if ( ! child )
                         return 0;
-                
+
                 child_class = idmef_class_get_child_class(parent_class, child_id);                
                 which = path->elem[depth].index;
 
                 if ( which == INDEX_FORBIDDEN )
                         return idmef_path_get_internal(value, path, depth + 1, child, child_class);
                 
-                if ( which == INDEX_UNDEFINED )
+                if ( which == INDEX_UNDEFINED || which == IDMEF_LIST_APPEND || which == IDMEF_LIST_PREPEND )
                         return idmef_path_get_list_internal(value, path, depth + 1, child, child_class);
                 
                 return idmef_path_get_nth_internal(value, path, depth + 1, child, child_class, which);
         }
 
-        if ( parent_class == -1 || path->elem[path->depth - 1].value_type == IDMEF_VALUE_TYPE_ENUM ) {
+        if ( parent_class < 0 || path->elem[path->depth - 1].value_type == IDMEF_VALUE_TYPE_ENUM ) {
                 *value = parent;
                 return 1;
         }
@@ -309,7 +308,7 @@ static int idmef_path_get_internal(idmef_value_t **value, idmef_path_t *path,
 }
 
 
-static void delete_listed_child(void *parent, idmef_class_id_t class, idmef_path_element_t *elem)
+static void delete_listed_child(void *parent, idmef_class_id_t class, const idmef_path_element_t *elem)
 {
         int ret;
         void *obj;
@@ -327,12 +326,12 @@ static void delete_listed_child(void *parent, idmef_class_id_t class, idmef_path
 
 
 
-static int _idmef_path_set(idmef_path_t *path, idmef_message_t *message, idmef_value_t *value, prelude_bool_t *delete_list)
+static int _idmef_path_set(const idmef_path_t *path, idmef_message_t *message, idmef_value_t *value, prelude_bool_t *delete_list)
 {
         int i, ret, index;
         void *ptr, *child;
         idmef_value_type_id_t tid;
-        idmef_path_element_t *elem;
+        const idmef_path_element_t *elem;
         idmef_class_id_t class, parent_class;
         
         ptr = message;
@@ -366,7 +365,7 @@ static int _idmef_path_set(idmef_path_t *path, idmef_message_t *message, idmef_v
                 
                 ptr = child;
                 parent_class = class;
-                
+
                 class = idmef_class_get_child_class(class, elem->position);                
                 assert( ! (class < 0 && i < path->depth - 1) );
         }
@@ -418,7 +417,7 @@ static int do_idmef_value_iterate(idmef_value_t *value, value_list_t *vl)
  *
  * Returns: The number of element retrieved, or a negative value if an error occured.
  */
-int idmef_path_get(idmef_path_t *path, idmef_message_t *message, idmef_value_t **ret)
+int idmef_path_get(const idmef_path_t *path, idmef_message_t *message, idmef_value_t **ret)
 {
         return idmef_path_get_internal(ret, path, 0, message, IDMEF_CLASS_ID_MESSAGE);
 }
@@ -435,10 +434,10 @@ int idmef_path_get(idmef_path_t *path, idmef_message_t *message, idmef_value_t *
  *
  * Returns: 0 on success, a negative value if an error occured.
  */
-int idmef_path_set(idmef_path_t *path, idmef_message_t *message, idmef_value_t *value)
+int idmef_path_set(const idmef_path_t *path, idmef_message_t *message, idmef_value_t *value)
 {
         prelude_bool_t delete_list = TRUE;
-        idmef_path_element_t *elem = &path->elem[path->depth - 1];
+        const idmef_path_element_t *elem = &path->elem[path->depth - 1];
         
         /*
          * Allow raw list copy (example: alert.source = alert.source,
@@ -532,6 +531,7 @@ static int idmef_path_parse_new(idmef_path_t *path, const char *buffer)
         char *endptr, *ptr, *ptr2;
         idmef_class_child_id_t child = 0;
         idmef_class_id_t class, prev_class = 0;
+        idmef_value_type_id_t vtype;
         
         len = strlen(buffer) + 1;
         if ( len >= sizeof(path->name) )
@@ -581,25 +581,20 @@ static int idmef_path_parse_new(idmef_path_t *path, const char *buffer)
 
                 prev_class = class;
 
-                /* The last object may not be a structure */
-                class = idmef_class_get_child_class(class, child);
-                if ( class < 0 && ! is_last )
+                /* The last object may not be a structure */                
+                vtype = path->elem[depth].value_type = idmef_class_get_child_value_type(class, child);
+                if ( vtype != IDMEF_VALUE_TYPE_CLASS && vtype != IDMEF_VALUE_TYPE_ENUM && ! is_last )
                         return prelude_error_verbose(PRELUDE_ERROR_GENERIC,
                                                      "IDMEF element '%s' is a leaf and thus has no child '%s'",
                                                      ptr, endptr + 1);
-                
-                path->elem[depth].class = class;
-                path->elem[depth].value_type = idmef_class_get_child_value_type(class, child);
-                
+
+                class = path->elem[depth].class = idmef_class_get_child_class(class, child);
                 if ( ++depth == MAX_DEPTH )
                         return prelude_error(PRELUDE_ERROR_IDMEF_PATH_DEPTH);
                 
         } while ( ! is_last );
         
         path->depth = depth;
-
-        path->elem[depth - 1].class = idmef_class_get_child_class(prev_class, child);
-        path->elem[depth - 1].value_type = idmef_class_get_child_value_type(prev_class, child);
         
         return 0;
 }
@@ -938,8 +933,8 @@ int idmef_path_make_child(idmef_path_t *path, const char *child_name, unsigned i
                 path->elem[path->depth - 1].index = (index < 0) ? INDEX_UNDEFINED : index;
         else
                 path->elem[path->depth - 1].index = INDEX_FORBIDDEN;
-        
-        path->elem[path->depth - 1].class = idmef_class_get_child_class(class, child);
+
+        path->elem[path->depth - 1].class = idmef_class_get_child_class(class, child);        
         path->elem[path->depth - 1].value_type = idmef_class_get_child_value_type(class, child);
              
         return 0;
@@ -1192,7 +1187,7 @@ const char *idmef_path_get_name(const idmef_path_t *path, int depth)
         
         elem = &path->elem[depth];
         
-        if ( elem->class == -1 || elem->value_type == IDMEF_VALUE_TYPE_ENUM )
+        if ( elem->class < 0 || elem->value_type == IDMEF_VALUE_TYPE_ENUM )
                 ret = idmef_class_get_child_name(path->elem[depth - 1].class, elem->position);
         else
                 ret = idmef_class_get_name(elem->class);
