@@ -40,7 +40,8 @@
 #include "idmef-value-type.h"
 
 
-#define CLASS_OPERATOR  IDMEF_CRITERION_OPERATOR_NULL|IDMEF_CRITERION_OPERATOR_NOT
+#define CLASS_OPERATOR  IDMEF_CRITERION_OPERATOR_NULL|IDMEF_CRITERION_OPERATOR_NOT| \
+                        IDMEF_CRITERION_OPERATOR_EQUAL
 
 #define DATA_OPERATOR    IDMEF_CRITERION_OPERATOR_EQUAL|IDMEF_CRITERION_OPERATOR_NOT| \
                          IDMEF_CRITERION_OPERATOR_LESSER|IDMEF_CRITERION_OPERATOR_GREATER
@@ -242,16 +243,16 @@ static int enum_write(const idmef_value_type_t *src, prelude_string_t *out)
 static int time_compare(const idmef_value_type_t *t1, const idmef_value_type_t *t2,
                         size_t size, idmef_criterion_operator_t op)
 {
-	double time1 = idmef_time_get_sec(t1->data.time_val) + idmef_time_get_usec(t1->data.time_val) * 1e-6;
-	double time2 = idmef_time_get_sec(t2->data.time_val) + idmef_time_get_usec(t2->data.time_val) * 1e-6;
+        int ret;
 
-        if ( op & IDMEF_CRITERION_OPERATOR_EQUAL && time1 == time2 )
+        ret = idmef_time_compare(t1->data.time_val, t2->data.time_val);
+        if ( op & IDMEF_CRITERION_OPERATOR_EQUAL && ret == 0 )
                 return 0;
         
-        else if ( op & IDMEF_CRITERION_OPERATOR_LESSER && time1 < time2 )
+        else if ( op & IDMEF_CRITERION_OPERATOR_LESSER && ret < 0 )
                 return 0;
 
-        else if ( op & IDMEF_CRITERION_OPERATOR_GREATER && time1 > time2 )
+        else if ( op & IDMEF_CRITERION_OPERATOR_GREATER && ret > 0 )
                 return 0;
 
         return -1;
@@ -311,11 +312,17 @@ static void time_destroy(idmef_value_type_t *type)
 static int string_compare(const idmef_value_type_t *t1, const idmef_value_type_t *t2,
                           size_t size, idmef_criterion_operator_t op)
 {
-        const char *s1, *s2;
+        const char *s1 = NULL, *s2 = NULL;
+
+        if ( t1->data.string_val )
+                s1 = prelude_string_get_string(t1->data.string_val);
+
+        if ( t2->data.string_val )
+                s2 = prelude_string_get_string(t2->data.string_val);
+
+        if ( ! s1 || ! s2 )
+                return (s1) ? 1 : -1;
         
-        s1 = prelude_string_get_string(t1->data.string_val);
-        s2 = prelude_string_get_string(t2->data.string_val);
-                
         if ( op == (IDMEF_CRITERION_OPERATOR_EQUAL|IDMEF_CRITERION_OPERATOR_NOCASE) && strcasecmp(s1, s2) == 0 )
                 return 0;
         
@@ -375,17 +382,8 @@ static int data_compare(const idmef_value_type_t *t1, const idmef_value_type_t *
                         size_t len, idmef_criterion_operator_t op)
 {
         int ret;
-        size_t len1, len2;
-        idmef_data_t *d1 = t1->data.data_val, *d2 = t2->data.data_val;
-        
-        len1 = idmef_data_get_len(d1);
-        len2 = idmef_data_get_len(d2);
-
-        if ( len1 == len2 )
-                ret = memcmp(idmef_data_get_data(d1), idmef_data_get_data(d2), len2);
-        else 
-                ret = (len1 > len2) ? 1 : -1;   
         
+        ret = idmef_data_compare(t1->data.data_val, t2->data.data_val);        
         if ( ret == 0 && op & IDMEF_CRITERION_OPERATOR_EQUAL )
                 return 0;
 
@@ -438,6 +436,14 @@ static void data_destroy(idmef_value_type_t *type)
 /*
  *
  */
+static int class_compare(const idmef_value_type_t *c1,
+                         const idmef_value_type_t *c2, size_t len, idmef_criterion_operator_t op)
+{
+        return idmef_class_compare(c1->data.class_val.class_id,
+                                   c1->data.class_val.object, c2->data.class_val.object);
+}
+
+
 static int class_copy(const idmef_value_type_t *src, void *dst, size_t size)
 {
         return idmef_class_copy(src->data.class_val.class_id, src->data.class_val.object, dst);
@@ -488,7 +494,8 @@ static const idmef_value_type_operation_t ops_tbl[] = {
         { "enum", sizeof(idmef_value_type_enum_t), INTEGER_OPERATOR, enum_copy,
           generic_clone, NULL, generic_compare, enum_read, enum_write,            },
         { "list", 0, 0, NULL, NULL, NULL, NULL, NULL, NULL                        },
-        { "class", 0, CLASS_OPERATOR, class_copy, class_clone, class_destroy, NULL, NULL, NULL },
+        { "class", 0, CLASS_OPERATOR, class_copy,
+          class_clone, class_destroy, class_compare, NULL, NULL                   },
 };
 
 
@@ -571,8 +578,11 @@ int idmef_value_type_compare(const idmef_value_type_t *type1,
                                              idmef_value_type_to_string(type1->id));
         
         ret = ops_tbl[type1->id].compare(type1, type2, ops_tbl[type1->id].len, op & ~IDMEF_CRITERION_OPERATOR_NOT);
+        if ( ret < 0 ) /* not an error -> no match */
+                ret = 1; 
+        
         if ( op & IDMEF_CRITERION_OPERATOR_NOT )
-                return (ret == 0) ? -1 : 0;
+                return (ret == 0) ? 1 : 0;
         else
                 return ret;
 }
