@@ -40,9 +40,9 @@ typedef struct idmef_path idmef_path_t;
 #include "idmef-value.h"
 #include "idmef-tree-wrap.h"
 
-int idmef_path_get(idmef_path_t *path, idmef_message_t *message, idmef_value_t **ret);
+int idmef_path_get(const idmef_path_t *path, idmef_message_t *message, idmef_value_t **ret);
 
-int idmef_path_set(idmef_path_t *path, idmef_message_t *message, idmef_value_t *value);
+int idmef_path_set(const idmef_path_t *path, idmef_message_t *message, idmef_value_t *value);
 
 int idmef_path_new(idmef_path_t **path, const char *format, ...);
 int idmef_path_new_v(idmef_path_t **path, const char *format, va_list args);
@@ -82,6 +82,7 @@ prelude_bool_t idmef_path_is_list(idmef_path_t *path, int depth);
          
 unsigned int idmef_path_get_depth(const idmef_path_t *path);
 
+#ifndef SWIG         
 void _idmef_path_cache_lock(void);
 
 void _idmef_path_cache_reinit(void);
@@ -89,7 +90,8 @@ void _idmef_path_cache_reinit(void);
 void _idmef_path_cache_unlock(void);
 
 void _idmef_path_cache_destroy(void);
-         
+#endif
+
 #ifdef __cplusplus
  }
 #endif
