@@ -31,13 +31,6 @@
 
 #include "config.h"
 
-#include <alloca.h>
-#include <stdbool.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <time.h>
 #include "ftw_.h"
 #include "getaddrinfo.h"
 #include "gettext.h"
@@ -61,11 +54,13 @@
 #include "vsnprintf.h"
 #include "wcwidth.h"
 #include "xsize.h"
-#if HAVE_WCHAR_H && HAVE_WCTYPE_H
+
+#if HAVE_WCHAR_H
 # include "mbchar.h"
 #endif
 #if HAVE_MBRTOWC
 # include "mbuiter.h"
 #endif
 
+
 #endif /* _LIBPRELUDE_LIBMISSING_H */
