@@ -128,6 +128,15 @@ extern char *_prelude_internal_argv[1024];
 prelude_option_t *_prelude_generic_optlist = NULL;
 
 
+
+static int client_write_cb(prelude_msgbuf_t *msgbuf, prelude_msg_t *msg)
+{
+        prelude_client_send_msg(prelude_msgbuf_get_data(msgbuf), msg);
+        return 0;
+}
+
+
+
 static int generate_md5sum(const char *filename, prelude_string_t *out)
 {
         void *data;
@@ -246,7 +255,7 @@ static void heartbeat_expire_cb(void *data)
                 return;
         
         idmef_heartbeat_set_create_time(heartbeat, time);
-        idmef_heartbeat_set_analyzer(heartbeat, idmef_analyzer_ref(client->analyzer), 0);
+        idmef_heartbeat_set_analyzer(heartbeat, idmef_analyzer_ref(client->analyzer), IDMEF_LIST_PREPEND);
         
         if ( client->heartbeat_cb ) {
                 client->heartbeat_cb(client, message);
@@ -499,6 +508,9 @@ static int set_node_address(prelude_option_t *opt, const char *optarg, prelude_s
         idmef_address_t *addr;
         prelude_option_context_t *octx;
         prelude_client_t *ptr = context;
+
+        if ( prelude_option_search_context(opt, optarg) )
+                return 0;
         
         ret = idmef_analyzer_new_node(ptr->analyzer, &node);
         if ( ret < 0 )
@@ -693,21 +705,13 @@ static int get_manager_addr(prelude_option_t *opt, prelude_string_t *out, void *
 
 
 
-static int send_reply(prelude_msgbuf_t *msgbuf, prelude_msg_t *msg)
-{
-        prelude_connection_t *conn = prelude_msgbuf_get_data(msgbuf);
-        return prelude_connection_send(conn, msg);
-}
-
-
-
 static int connection_pool_event_cb(prelude_connection_pool_t *pool,
                                     prelude_connection_pool_event_t event,
                                     prelude_connection_t *conn)
 {
         int ret;
-        prelude_msgbuf_t *msgbuf;
         prelude_client_t *client;
+        prelude_msgbuf_t *msgbuf;
         prelude_msg_t *msg = NULL;
         
         if ( event != PRELUDE_CONNECTION_POOL_EVENT_INPUT )
@@ -716,36 +720,21 @@ static int connection_pool_event_cb(prelude_connection_pool_t *pool,
         do {
                 ret = prelude_connection_recv(conn, &msg);
         } while ( ret < 0 && prelude_error_get_code(ret) == PRELUDE_ERROR_EAGAIN );
-
+                
         if ( ret < 0 )
                 return ret;
-        
-        if ( prelude_msg_get_tag(msg) != PRELUDE_MSG_OPTION_REQUEST ) {
-                prelude_msg_destroy(msg);
-                return ret;
-        }
-        
-        ret = prelude_msgbuf_new(&msgbuf);
-        if ( ret < 0 ) {
-                prelude_msg_destroy(msg);
-                return ret;
-        }
-        
+
         client = prelude_connection_pool_get_data(pool);
         
-        prelude_msgbuf_set_data(msgbuf, conn);
-        prelude_msgbuf_set_callback(msgbuf, send_reply);
-        
-        prelude_thread_mutex_lock(&client->msgbuf_lock);
-        
-        ret = prelude_option_process_request(client, msg, msgbuf);        
-        prelude_msgbuf_mark_end(client->msgbuf);
-        
-        prelude_thread_mutex_unlock(&client->msgbuf_lock);
+        ret = prelude_connection_new_msgbuf(conn, &msgbuf);
+        if ( ret < 0 )
+                return ret;
+                
+        ret = prelude_client_handle_msg_default(client, msg, msgbuf);
 
-        prelude_msgbuf_destroy(msgbuf);
         prelude_msg_destroy(msg);
-        
+        prelude_msgbuf_destroy(msgbuf);
+
         return ret;
 }
 
@@ -807,32 +796,6 @@ static int set_profile(prelude_option_t *opt, const char *optarg, prelude_string
 
 
 
-
-static int client_write_msgbuf(prelude_msgbuf_t *msgbuf, prelude_msg_t *msg)
-{
-        prelude_client_send_msg(prelude_msgbuf_get_data(msgbuf), msg);
-        return 0;
-}
-
-
-
-static int create_heartbeat_msgbuf(prelude_client_t *client)
-{
-        int ret;
-        
-        ret = prelude_msgbuf_new(&client->msgbuf);
-        if ( ret < 0 )
-                return ret;
-
-        prelude_msgbuf_set_data(client->msgbuf, client);
-        prelude_msgbuf_set_callback(client->msgbuf, client_write_msgbuf);
-        
-        return 0;
-}
-
-
-
-
 static void _prelude_client_destroy(prelude_client_t *client)
 {
         if ( client->profile )
@@ -861,6 +824,23 @@ static void _prelude_client_destroy(prelude_client_t *client)
 
 
 
+static int handle_client_error(prelude_client_t *client, int error)
+{
+        prelude_error_code_t code;
+        prelude_error_source_t source;
+        
+        code = prelude_error_get_code(error);
+        source = prelude_error_get_source(error);
+        
+        if ( error < 0 && (code == PRELUDE_ERROR_PROFILE || source == PRELUDE_ERROR_SOURCE_CONFIG_ENGINE) ) {
+                char *tmp = strdup(_prelude_thread_get_error());
+                error = prelude_error_verbose(code, "%s\n%s", tmp, prelude_client_get_setup_error(client));
+                free(tmp);
+        }
+        
+        return error;
+}
+
 
 
 int _prelude_client_register_options(void)
@@ -869,9 +849,6 @@ int _prelude_client_register_options(void)
         prelude_option_t *opt;
         prelude_option_t *root_list;
 
-        if ( _prelude_generic_optlist )
-                return 0;
-
         prelude_option_new_root(&_prelude_generic_optlist);
 
         ret = prelude_option_add(_prelude_generic_optlist, &root_list,
@@ -1021,7 +998,7 @@ int prelude_client_new(prelude_client_t **client, const char *profile)
         ret = prelude_connection_pool_new(&new->cpool, new->profile, new->permission);
         if ( ret < 0 )
                 return ret;
-        
+
         prelude_connection_pool_set_data(new->cpool, new);
         prelude_connection_pool_set_flags(new->cpool, prelude_connection_pool_get_flags(new->cpool) |
                                           PRELUDE_CONNECTION_POOL_FLAGS_RECONNECT | PRELUDE_CONNECTION_POOL_FLAGS_FAILOVER);
@@ -1029,13 +1006,14 @@ int prelude_client_new(prelude_client_t **client, const char *profile)
 
         
         setup_heartbeat_timer(new, DEFAULT_HEARTBEAT_INTERVAL);
+
         
-        ret = create_heartbeat_msgbuf(new);
+        ret = prelude_client_new_msgbuf(new, &new->msgbuf);
         if ( ret < 0 ) {
                 _prelude_client_destroy(new);
                 return ret;
         }
-        
+                
         *client = new;
         
         return 0;
@@ -1061,7 +1039,7 @@ int prelude_client_new(prelude_client_t **client, const char *profile)
 int prelude_client_init(prelude_client_t *client)
 {
         int ret;
-        prelude_string_t *err = NULL;
+        prelude_string_t *err;
         prelude_option_warning_t old_warnings;
         
         prelude_option_set_warnings(0, &old_warnings);
@@ -1072,16 +1050,16 @@ int prelude_client_init(prelude_client_t *client)
         prelude_option_set_warnings(old_warnings, NULL);
         
         if ( ret < 0 )
-                return ret;
+                return handle_client_error(client, ret);
 
         ret = _prelude_client_profile_init(client->profile);
         if ( ret < 0 )
-                return ret;
+                return handle_client_error(client, ret);
         
         ret = fill_client_infos(client, _prelude_internal_argv[0]);
         if ( ret < 0 )
-                return ret;
-        
+                return handle_client_error(client, ret);
+
         return 0;
 }
 
@@ -1120,13 +1098,13 @@ int prelude_client_start(prelude_client_t *client)
                 if ( ! client->cpool )
                         return prelude_error(PRELUDE_ERROR_CONNECTION_STRING);
                 
-                ret = prelude_client_profile_get_credentials(client->profile, &credentials);
+                ret = prelude_client_profile_get_credentials(client->profile, &credentials);                
                 if ( ret < 0 )
-                        return ret;
-
+                        return handle_client_error(client, ret);
+                
                 ret = prelude_connection_pool_init(client->cpool);
                 if ( ret < 0 )
-                        return ret;
+                        return handle_client_error(client, ret);
         }
         
         if ( (client->cpool || client->heartbeat_cb) && client->flags & PRELUDE_CLIENT_FLAGS_HEARTBEAT ) {
@@ -1137,7 +1115,7 @@ int prelude_client_start(prelude_client_t *client)
                 heartbeat_expire_cb(client);
                 client->status = CLIENT_STATUS_RUNNING;
         }
-        
+                
         return 0;
 }
 
@@ -1200,7 +1178,7 @@ void prelude_client_send_idmef(prelude_client_t *client, idmef_message_t *msg)
          */
         prelude_thread_mutex_lock(&client->msgbuf_lock);
         
-        _idmef_message_assign_messageid(msg, client->unique_ident);
+        _idmef_message_assign_missing(client, msg);
         idmef_message_write(msg, client->msgbuf);
         prelude_msgbuf_mark_end(client->msgbuf);
 
@@ -1274,15 +1252,13 @@ void prelude_client_set_heartbeat_cb(prelude_client_t *client,
  */
 void prelude_client_destroy(prelude_client_t *client, prelude_client_exit_status_t status)
 {
+        prelude_timer_destroy(&client->heartbeat_timer);
+        
         if ( status == PRELUDE_CLIENT_EXIT_STATUS_SUCCESS && client->flags & PRELUDE_CLIENT_FLAGS_HEARTBEAT ) {
                 client->status = CLIENT_STATUS_EXITING;
                 heartbeat_expire_cb(client);
         }
         
-        prelude_timer_lock_critical_region();
-        prelude_timer_destroy(&client->heartbeat_timer);
-        prelude_timer_unlock_critical_region();
-        
         _prelude_client_destroy(client);
 }
 
@@ -1369,6 +1345,9 @@ prelude_connection_permission_t prelude_client_get_required_permission(prelude_c
  */
 void prelude_client_set_required_permission(prelude_client_t *client, prelude_connection_permission_t permission)
 {
+        if ( permission & PRELUDE_CONNECTION_PERMISSION_IDMEF_READ )
+                prelude_connection_pool_set_event_handler(client->cpool, 0, NULL);
+        
         client->permission = permission;
         prelude_connection_pool_set_required_permission(client->cpool, permission);
 }
@@ -1441,56 +1420,109 @@ prelude_client_profile_t *prelude_client_get_profile(prelude_client_t *client)
  * the prelude_client_start() function, to know if the analyzer
  * need to be registered.
  *
+ * DEPRECATED: use standard error API.
+ *
  * Returns: TRUE if setup is needed, FALSE otherwise.
  */
 prelude_bool_t prelude_client_is_setup_needed(int error)
 {
-        prelude_error_code_t code = prelude_error_get_code(error);
+        /*
+         * Deprecated.
+         */
+        return FALSE;
+}
+
+
+
+const char *prelude_client_get_setup_error(prelude_client_t *client)
+{
+        int ret;
+        prelude_string_t *out, *perm;
+
+        ret = prelude_string_new(&out);
+        if ( ret < 0 )
+                return NULL;
         
-        return ( code == PRELUDE_ERROR_BACKUP_DIRECTORY     ||
-                 code == PRELUDE_ERROR_PROFILE              ||
-                 code == PRELUDE_ERROR_ANALYZERID_FILE      ||
-                 code == PRELUDE_ERROR_ANALYZERID_PARSE     ||
-                 code == PRELUDE_ERROR_TLS_KEY_FILE         ||
-                 code == PRELUDE_ERROR_TLS_CERTIFICATE_FILE ||
-                 code == PRELUDE_ERROR_TLS_CERTIFICATE_PARSE ||
-                 prelude_error_get_source(error) == PRELUDE_ERROR_SOURCE_CONFIG_ENGINE ) ? TRUE : FALSE;
+        if ( client->flags & PRELUDE_CLIENT_FLAGS_CONNECT ) { 
+                ret = prelude_string_new(&perm);
+                if ( ret < 0 ) {
+                        prelude_string_destroy(out);
+                        return NULL;
+                }
+                
+                prelude_connection_permission_to_string(client->permission, perm);
+
+                ret = prelude_string_sprintf(out, "\nProfile '%s' does not exist. In order to create it, please run:\n"
+                                             "prelude-adduser register %s \"%s\" <manager address> --uid %d --gid %d",
+                                             prelude_client_profile_get_name(client->profile),
+                                             prelude_client_profile_get_name(client->profile),
+                                             prelude_string_get_string(perm),
+                                             prelude_client_profile_get_uid(client->profile),
+                                             prelude_client_profile_get_gid(client->profile));                
+
+                prelude_string_destroy(perm);
+                
+        } else {
+                ret = prelude_string_sprintf(out, "\nProfile '%s' does not exist. In order to create it, please run:\n"
+                                             "prelude-adduser add %s --uid %d --gid %d",
+                                             prelude_client_profile_get_name(client->profile),
+                                             prelude_client_profile_get_name(client->profile),
+                                             prelude_client_profile_get_uid(client->profile),
+                                             prelude_client_profile_get_gid(client->profile));
+        }
+
+        if ( ret < 0 )
+                return NULL;
+
+        _prelude_thread_set_error(prelude_string_get_string(out));
+        prelude_string_destroy(out);
+                
+        return _prelude_thread_get_error();
 }
 
 
 
 void prelude_client_print_setup_error(prelude_client_t *client) 
 {
+        prelude_log(PRELUDE_LOG_WARN, "%s\n\n", prelude_client_get_setup_error(client));
+}
+
+
+
+int prelude_client_handle_msg_default(prelude_client_t *client, prelude_msg_t *msg, prelude_msgbuf_t *msgbuf)
+{
         int ret;
-        prelude_string_t *out;
-
-        if ( client->flags & PRELUDE_CLIENT_FLAGS_CONNECT ) {
-                ret = prelude_string_new(&out);
-                if ( ret < 0 )
-                        return;
-                
-                prelude_connection_permission_to_string(client->permission, out);
-
-                prelude_log(PRELUDE_LOG_WARN,
-                            "\nBasic file configuration does not exist. Please run :\n"
-                            "prelude-adduser register %s \"%s\" <manager address> --uid %d --gid %d\n"
-                            "program to setup the analyzer.\n\n"
-                            
-                            "Be aware that you should replace the \"<manager address>\" argument with\n"
-                            "the server address this analyzer is reporting to as argument.\n"
-                            "\"prelude-adduser\" should be called for each configured server address.\n\n",
-                            prelude_client_profile_get_name(client->profile), prelude_string_get_string(out),
-                            prelude_client_profile_get_uid(client->profile),
-                            prelude_client_profile_get_gid(client->profile));                
-
-                prelude_string_destroy(out);
-                
-        } else {
-                prelude_log(PRELUDE_LOG_WARN,
-                            "\nBasic file configuration does not exist. Please run :\n"
-                            "prelude-adduser add %s --uid %d --gid %d\n\n",
-                            prelude_client_profile_get_name(client->profile),
-                            prelude_client_profile_get_uid(client->profile),
-                            prelude_client_profile_get_gid(client->profile));
-        }
+        uint8_t tag;
+        
+        tag = prelude_msg_get_tag(msg);
+        if ( tag != PRELUDE_MSG_OPTION_REQUEST )
+                return prelude_error_verbose(PRELUDE_ERROR_GENERIC, "Unexpected message type '%d' received", tag);
+        
+        /*
+         * lock, handle the request, send reply.
+         */
+        prelude_thread_mutex_lock(&client->msgbuf_lock);
+
+        ret = prelude_option_process_request(client, msg, msgbuf);
+        prelude_msgbuf_mark_end(client->msgbuf);
+        
+        prelude_thread_mutex_unlock(&client->msgbuf_lock);
+        
+        return ret;
+}
+
+
+
+int prelude_client_new_msgbuf(prelude_client_t *client, prelude_msgbuf_t **msgbuf)
+{
+        int ret;
+
+        ret = prelude_msgbuf_new(msgbuf);
+        if ( ret < 0 )
+                return ret;
+
+        prelude_msgbuf_set_data(*msgbuf, client);
+        prelude_msgbuf_set_callback(*msgbuf, client_write_cb);
+
+        return 0;
 }
