@@ -71,18 +71,18 @@ static int config_save_value(config_t *cfg, int rtype, prelude_option_t *last, i
                         return prelude_error_from_errno(errno);
                 
                 if ( rtype == PRELUDE_MSG_OPTION_SET )
-                        return config_set(cfg, buf, NULL, NULL, line);
+                        return _config_set(cfg, buf, NULL, NULL, line);
 
                 else if ( is_last_cmd )
-                        return config_del(cfg, buf, NULL);
+                        return _config_del(cfg, buf, NULL);
                         
         }
         
         if ( rtype == PRELUDE_MSG_OPTION_SET ) 
-                ret = config_set(cfg, *prev, option, value, line);
+                ret = _config_set(cfg, *prev, option, value, line);
 
         else if ( is_last_cmd )
-                ret = config_del(cfg, *prev, option);
+                ret = _config_del(cfg, *prev, option);
         
         return ret;
 }
@@ -165,7 +165,7 @@ static int parse_request(prelude_client_t *client, int rtype, char *request, pre
         char *str, *value, *prev = NULL, *ptr = NULL;
         unsigned int line = 0;
         
-        ret = config_open(&cfg, prelude_client_get_config_filename(client));
+        ret = _config_open(&cfg, prelude_client_get_config_filename(client));
         if ( ret < 0 )
                 return ret;
         
@@ -195,7 +195,7 @@ static int parse_request(prelude_client_t *client, int rtype, char *request, pre
                 config_save_value(cfg, rtype, last, last_cmd, &prev, pname, (ent == 2) ? iname : ptr, &line);
         }
         
-        config_close(cfg);
+        _config_close(cfg);
         free(prev);
         
         return ret;
