@@ -906,3 +906,29 @@ void prelude_string_clear(prelude_string_t *string)
 
         else string->data.rwbuf = NULL;
 }
+
+
+
+/**
+ * prelude_string_compare:
+ * @str1: Pointer to a #prelude_string_t object to compare with @str2.
+ * @str2: Pointer to a #prelude_string_t object to compare with @str1.
+ *
+ * Returns: 0 if @str1 and @str2 value are equal, a negative value otherwise.
+ */
+int prelude_string_compare(const prelude_string_t *str1, const prelude_string_t *str2)
+{
+        if ( ! str1 && ! str2 )
+                return 0;
+
+        else if ( ! str1 || ! str2 )
+                return -1;
+        
+        else if ( str1->index != str2->index )
+                return -1;
+
+        if ( str1->index == 0 )
+                return 0;
+        
+        return strcmp(str1->data.robuf, str2->data.robuf);
+}
